# Olli

Olli searches your Loki logs and relays matching terms to Discord. Please read the [documentation](https://python-discord.github.io/olli/) to get started.

- [Documentation](https://python-discord.github.io/olli/)
- [Docker Image](https://ghcr.io/python-discord/olli)

## Contributing

Please open an issue before contributing features to discuss implementation.

## License

Olli is licensed under MIT.
